@@ -980,7 +980,9 @@ dragging it to its bottom-right corner.  See also
                   (/ 1.0 (float (cdr size))))))))
 
 (defun pdf-view--bounding-box-to-slice (bb)
-  "Convert a '(LEFT TOP RIGHT BOTTOM) bounding box to '(X Y WIDTH HEIGHT), the format accepted by `pdf-view-set-slice'."
+  "Convert bounding box BB to slice format for `pdf-view-set-slice'.
+BB is a list (LEFT TOP RIGHT BOTTOM).
+Returns a list (X Y WIDTH HEIGHT)."
   (let* ((margin (max 0 (or pdf-view-bounding-box-margin 0)))
          (halfmargin (/ margin 2)))
     (cl-destructuring-bind (left top right bottom) bb
@@ -1004,7 +1006,8 @@ See also `pdf-view-bounding-box-margin'."
            (append slice (and window (list window))))))
 
 (defun pdf-document-common-bounding-box (&optional file-or-buffer)
-  "Return the common bounding for all pages in document FILE-OR-BUFFER, as '(LEFT TOP RIGHT BOTTOM)."
+  "Return the common bounding box for all pages in FILE-OR-BUFFER.
+Returns a list (LEFT TOP RIGHT BOTTOM)."
   (let ((left 1.0)
         (top 1.0)
         (right 0.0)
@@ -1018,10 +1021,9 @@ See also `pdf-view-bounding-box-margin'."
     (list left top right bottom)))
 
 (defun pdf-view-set-slice-common-bounding-box (&optional window)
-  "Set the slice from the common bounding box, combined from all pages.
-
-The bounding box is calculated using the document in WINDOW, which defaults to `selected-window`.
+  "Set the slice from the common bounding box of all pages.
 
+WINDOW specifies which document to use; defaults to `selected-window'.
 A margin is added from `pdf-view-bounding-box-margin'."
   (interactive)
   (let* ((bb (pdf-document-common-bounding-box))
@@ -1841,21 +1843,22 @@ works only with bookmarks created by
       (pdf-view-bookmark-jump-handler bmk)
       (run-hooks 'bookmark-after-jump-hook))))
 
-(defun pdf-view-registerv-make ()
-  "Create a PDF register entry of the current position."
-  (registerv-make
-   (pdf-view-bookmark-make-record nil t t)
-   :print-func 'pdf-view-registerv-print-func
-   :jump-func 'pdf-view-bookmark-jump
-   :insert-func (lambda (bmk)
-                  (insert (format "%S" bmk)))))
+;; Register support using cl-defstruct (replaces obsolete registerv-make)
+(cl-defstruct (pdf-view-register
+               (:constructor nil)
+               (:constructor pdf-view-register--make (bookmark))
+               (:copier nil))
+  "A PDF position register entry."
+  bookmark)
 
-(defun pdf-view-registerv-print-func (bmk)
-  "Print a textual representation of bookmark BMK.
+(cl-defmethod register-val-jump-to ((val pdf-view-register) _arg)
+  "Jump to the PDF position stored in VAL."
+  (pdf-view-bookmark-jump (pdf-view-register-bookmark val)))
 
-This function is used as the `:print-func' property with
-`registerv-make'."
-  (let* ((file (bookmark-prop-get bmk 'filename))
+(cl-defmethod register-val-describe ((val pdf-view-register) _verbose)
+  "Print a description of the PDF position stored in VAL."
+  (let* ((bmk (pdf-view-register-bookmark val))
+         (file (bookmark-prop-get bmk 'filename))
          (buffer (find-buffer-visiting file))
          (page (bookmark-prop-get bmk 'page))
          (origin (bookmark-prop-get bmk 'origin)))
@@ -1868,6 +1871,15 @@ This function is used as the `:print-func' property with
                        (round (* 100 (cdr origin)))
                      0)))))
 
+(cl-defmethod register-val-insert ((val pdf-view-register))
+  "Insert the PDF bookmark stored in VAL."
+  (insert (format "%S" (pdf-view-register-bookmark val))))
+
+(defun pdf-view-registerv-make ()
+  "Create a PDF register entry of the current position."
+  (pdf-view-register--make
+   (pdf-view-bookmark-make-record nil t t)))
+
 (defmacro pdf-view-with-register-alist (&rest body)
   "Setup the proper binding for `register-alist' in BODY.
 
